diff --git a/Makefile b/Makefile
index f163804f..8f813b6b 100644
--- a/Makefile
+++ b/Makefile
@@ -19,29 +19,32 @@ all: docs pip src runtime
 appbundle: docs
 	./pkg/mac/build.sh
 
-install-node:
-	cd web && yarn install
-
 bundle:
 	cd web && yarn run bundle
 
 bundle-dev:
 	cd web && yarn run bundle:dev
 
+install-node:
+	cd web && yarn install
+
 linter:
 	cd web && yarn run linter
 
-check: install-node bundle linter
-	cd web && pycodestyle --config=.pycodestyle . && yarn run karma start --single-run && python regression/runtests.py
+check: install-node bundle check-pep8 check-js check-python check-feature
 
 check-pep8:
 	cd web && pycodestyle --config=.pycodestyle .
 
 check-python:
-	cd web && python regression/runtests.py --exclude feature_tests
+	cd web && python -m pytest --tb=short -q \
+	--json=regression/test_result.json --log-file-level=DEBUG \
+	--log-file=regression/regression.log pgadmin
 
 check-feature: install-node bundle
-	cd web && python regression/runtests.py --pkg feature_tests
+	cd web && python -m pytest --tb=short -q \
+	--json=regression/test_result.json --log-file-level=DEBUG \
+	--log-file=regression/regression.log regression/feature_tests
 
 check-js: install-node linter
 	cd web && yarn run karma start --single-run
diff --git a/web/package.json b/web/package.json
index 98443f45..0e895968 100644
--- a/web/package.json
+++ b/web/package.json
@@ -101,7 +101,7 @@
     "bundle": "cross-env NODE_ENV=production yarn run bundle:dev",
     "test:karma-once": "yarn run linter && yarn run karma start --single-run",
     "test:karma": "yarn run linter && yarn run karma start",
-    "test:unit": "yarn run linter && pytest -q pgadmin",
+    "test:unit": "yarn run pep8 && python -m pytest -q pgadmin",
     "test:feature": "yarn run bundle && python regression/runtests.py --pkg feature_tests",
     "test": "yarn run test:karma-once && yarn run bundle && yarn test:unit && python regression/runtests.py --pkg feature_tests",
     "pep8": "pycodestyle --config=.pycodestyle ."
diff --git a/web/pgadmin/browser/server_groups/servers/tablespaces/tests/test_tbspc_get.py b/web/pgadmin/browser/server_groups/servers/tablespaces/tests/test_tbspc_get.py
index f57646c2..bb1883a3 100644
--- a/web/pgadmin/browser/server_groups/servers/tablespaces/tests/test_tbspc_get.py
+++ b/web/pgadmin/browser/server_groups/servers/tablespaces/tests/test_tbspc_get.py
@@ -72,7 +72,7 @@ class TestTablespaceGet:
             should.be.none
         json_response | should.have.key('oid')
         json_response | should.have.key('spclocation') > \
-            should.be.equal.to(self.server['tablespace_path'])
+            should.be.equal.to(self.server['tablespace_path'].rstrip('/\\'))
         json_response | should.have.key('acl') > \
             should.be.none
         json_response | should.have.key('spcuser') > \
diff --git a/web/regression/README b/web/regression/README
index 7e668cfd..d2dcf462 100644
--- a/web/regression/README
+++ b/web/regression/README
@@ -145,35 +145,34 @@ Python Tests:
      run 'cd web/regression'
 
 - Execute the test framework for all nodes
-     run 'python runtests.py --pkg all' or just:
-         'python runtests.py'
+     run 'python -m pytest -q pgadmin regression/feature_tests'
 
 - Execute test framework for entire package
 
      Example 1) Run test framework for 'browser' package
-     run 'python runtests.py --pkg browser'
+     run 'python -m pytest -q pgadmin/browser'
 
      Example 2) Run test framework for 'database' package
-     run 'python runtests.py --pkg browser.server_groups.servers.databases'
+     run 'python -m pytest -q pgadmin/browser/server_groups/servers/databases'
 
      Example 3) Run feature tests
-     run 'python runtests.py --pkg feature_tests
+     run 'python -m pytest -q regression/feature_tests'
 
 - Execute test framework for single node at a time
 
      Example 1) Run test framework for 'browser' node
-     run 'python runtests.py --pkg browser.server_groups.tests'
+     run 'python -m pytest -q pgadmin --ignore pgadmin/browser/server_groups/tests'
 
      Example 2) Run test framework for 'database' node
-     run 'python runtests.py --pkg browser.server_groups.servers.databases.tests'
+     run 'python -m pytest -q pgadmin/browser/server_groups/servers/databases/tests'
 
 - Exclude a package and its subpackages when running tests:
 
     Example: exclude feature tests but run all others:
-    run 'python runtests.py --exclude feature_tests'
+    run 'python -m pytest -q pgadmin'
 
     Example: exclude multiple packages:
-    run 'python runtests.py --exclude browser.server_groups.servers.databases,browser.server_groups.servers.tablespaces'
+    run 'python -m pytest -q pgadmin --ignore pgadmin/browser/server_groups/servers/databases --ignore pgadmin/browser/server_groups/servers/tablespaces'
 
 Javascript Tests:
 
-- 
2.17.0

